/****************************************************************************
** Meta object code from reading C++ file 'progressmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepim/progresswidget/progressmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'progressmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KPIM__ProgressItem_t {
    QByteArrayData data[14];
    char stringdata0[258];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__ProgressItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__ProgressItem_t qt_meta_stringdata_KPIM__ProgressItem = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KPIM::ProgressItem"
QT_MOC_LITERAL(1, 19, 17), // "progressItemAdded"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 19), // "KPIM::ProgressItem*"
QT_MOC_LITERAL(4, 58, 20), // "progressItemProgress"
QT_MOC_LITERAL(5, 79, 21), // "progressItemCompleted"
QT_MOC_LITERAL(6, 101, 20), // "progressItemCanceled"
QT_MOC_LITERAL(7, 122, 18), // "progressItemStatus"
QT_MOC_LITERAL(8, 141, 17), // "progressItemLabel"
QT_MOC_LITERAL(9, 159, 24), // "progressItemCryptoStatus"
QT_MOC_LITERAL(10, 184, 32), // "KPIM::ProgressItem::CryptoStatus"
QT_MOC_LITERAL(11, 217, 29), // "progressItemUsesBusyIndicator"
QT_MOC_LITERAL(12, 247, 4), // "item"
QT_MOC_LITERAL(13, 252, 5) // "value"

    },
    "KPIM::ProgressItem\0progressItemAdded\0"
    "\0KPIM::ProgressItem*\0progressItemProgress\0"
    "progressItemCompleted\0progressItemCanceled\0"
    "progressItemStatus\0progressItemLabel\0"
    "progressItemCryptoStatus\0"
    "KPIM::ProgressItem::CryptoStatus\0"
    "progressItemUsesBusyIndicator\0item\0"
    "value"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__ProgressItem[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       4,    2,   57,    2, 0x06 /* Public */,
       5,    1,   62,    2, 0x06 /* Public */,
       6,    1,   65,    2, 0x06 /* Public */,
       7,    2,   68,    2, 0x06 /* Public */,
       8,    2,   73,    2, 0x06 /* Public */,
       9,    2,   78,    2, 0x06 /* Public */,
      11,    2,   83,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::UInt,    2,    2,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    2,    2,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 10,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool,   12,   13,

       0        // eod
};

void KPIM::ProgressItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ProgressItem *_t = static_cast<ProgressItem *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->progressItemAdded((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        case 1: _t->progressItemProgress((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 2: _t->progressItemCompleted((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        case 3: _t->progressItemCanceled((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        case 4: _t->progressItemStatus((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 5: _t->progressItemLabel((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 6: _t->progressItemCryptoStatus((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< KPIM::ProgressItem::CryptoStatus(*)>(_a[2]))); break;
        case 7: _t->progressItemUsesBusyIndicator((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ProgressItem::*_t)(KPIM::ProgressItem * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressItem::progressItemAdded)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ProgressItem::*_t)(KPIM::ProgressItem * , unsigned int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressItem::progressItemProgress)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ProgressItem::*_t)(KPIM::ProgressItem * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressItem::progressItemCompleted)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ProgressItem::*_t)(KPIM::ProgressItem * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressItem::progressItemCanceled)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (ProgressItem::*_t)(KPIM::ProgressItem * , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressItem::progressItemStatus)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (ProgressItem::*_t)(KPIM::ProgressItem * , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressItem::progressItemLabel)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (ProgressItem::*_t)(KPIM::ProgressItem * , KPIM::ProgressItem::CryptoStatus );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressItem::progressItemCryptoStatus)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (ProgressItem::*_t)(KPIM::ProgressItem * , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressItem::progressItemUsesBusyIndicator)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject KPIM::ProgressItem::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KPIM__ProgressItem.data,
      qt_meta_data_KPIM__ProgressItem,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::ProgressItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::ProgressItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__ProgressItem.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KPIM::ProgressItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KPIM::ProgressItem::progressItemAdded(KPIM::ProgressItem * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KPIM::ProgressItem::progressItemProgress(KPIM::ProgressItem * _t1, unsigned int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KPIM::ProgressItem::progressItemCompleted(KPIM::ProgressItem * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KPIM::ProgressItem::progressItemCanceled(KPIM::ProgressItem * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KPIM::ProgressItem::progressItemStatus(KPIM::ProgressItem * _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KPIM::ProgressItem::progressItemLabel(KPIM::ProgressItem * _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KPIM::ProgressItem::progressItemCryptoStatus(KPIM::ProgressItem * _t1, KPIM::ProgressItem::CryptoStatus _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KPIM::ProgressItem::progressItemUsesBusyIndicator(KPIM::ProgressItem * _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
struct qt_meta_stringdata_KPIM__ProgressManager_t {
    QByteArrayData data[17];
    char stringdata0[338];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__ProgressManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__ProgressManager_t qt_meta_stringdata_KPIM__ProgressManager = {
    {
QT_MOC_LITERAL(0, 0, 21), // "KPIM::ProgressManager"
QT_MOC_LITERAL(1, 22, 17), // "progressItemAdded"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 19), // "KPIM::ProgressItem*"
QT_MOC_LITERAL(4, 61, 20), // "progressItemProgress"
QT_MOC_LITERAL(5, 82, 21), // "progressItemCompleted"
QT_MOC_LITERAL(6, 104, 20), // "progressItemCanceled"
QT_MOC_LITERAL(7, 125, 18), // "progressItemStatus"
QT_MOC_LITERAL(8, 144, 17), // "progressItemLabel"
QT_MOC_LITERAL(9, 162, 24), // "progressItemCryptoStatus"
QT_MOC_LITERAL(10, 187, 32), // "KPIM::ProgressItem::CryptoStatus"
QT_MOC_LITERAL(11, 220, 29), // "progressItemUsesBusyIndicator"
QT_MOC_LITERAL(12, 250, 18), // "showProgressDialog"
QT_MOC_LITERAL(13, 269, 25), // "slotStandardCancelHandler"
QT_MOC_LITERAL(14, 295, 4), // "item"
QT_MOC_LITERAL(15, 300, 12), // "slotAbortAll"
QT_MOC_LITERAL(16, 313, 24) // "slotTransactionCompleted"

    },
    "KPIM::ProgressManager\0progressItemAdded\0"
    "\0KPIM::ProgressItem*\0progressItemProgress\0"
    "progressItemCompleted\0progressItemCanceled\0"
    "progressItemStatus\0progressItemLabel\0"
    "progressItemCryptoStatus\0"
    "KPIM::ProgressItem::CryptoStatus\0"
    "progressItemUsesBusyIndicator\0"
    "showProgressDialog\0slotStandardCancelHandler\0"
    "item\0slotAbortAll\0slotTransactionCompleted"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__ProgressManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,
       4,    2,   77,    2, 0x06 /* Public */,
       5,    1,   82,    2, 0x06 /* Public */,
       6,    1,   85,    2, 0x06 /* Public */,
       7,    2,   88,    2, 0x06 /* Public */,
       8,    2,   93,    2, 0x06 /* Public */,
       9,    2,   98,    2, 0x06 /* Public */,
      11,    2,  103,    2, 0x06 /* Public */,
      12,    0,  108,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    1,  109,    2, 0x0a /* Public */,
      15,    0,  112,    2, 0x0a /* Public */,
      16,    1,  113,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::UInt,    2,    2,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    2,    2,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 10,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool,    2,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,   14,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,   14,

       0        // eod
};

void KPIM::ProgressManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ProgressManager *_t = static_cast<ProgressManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->progressItemAdded((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        case 1: _t->progressItemProgress((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 2: _t->progressItemCompleted((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        case 3: _t->progressItemCanceled((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        case 4: _t->progressItemStatus((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 5: _t->progressItemLabel((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 6: _t->progressItemCryptoStatus((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< KPIM::ProgressItem::CryptoStatus(*)>(_a[2]))); break;
        case 7: _t->progressItemUsesBusyIndicator((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 8: _t->showProgressDialog(); break;
        case 9: _t->slotStandardCancelHandler((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        case 10: _t->slotAbortAll(); break;
        case 11: _t->slotTransactionCompleted((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ProgressManager::*_t)(KPIM::ProgressItem * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressManager::progressItemAdded)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ProgressManager::*_t)(KPIM::ProgressItem * , unsigned int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressManager::progressItemProgress)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ProgressManager::*_t)(KPIM::ProgressItem * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressManager::progressItemCompleted)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ProgressManager::*_t)(KPIM::ProgressItem * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressManager::progressItemCanceled)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (ProgressManager::*_t)(KPIM::ProgressItem * , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressManager::progressItemStatus)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (ProgressManager::*_t)(KPIM::ProgressItem * , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressManager::progressItemLabel)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (ProgressManager::*_t)(KPIM::ProgressItem * , KPIM::ProgressItem::CryptoStatus );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressManager::progressItemCryptoStatus)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (ProgressManager::*_t)(KPIM::ProgressItem * , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressManager::progressItemUsesBusyIndicator)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (ProgressManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressManager::showProgressDialog)) {
                *result = 8;
                return;
            }
        }
    }
}

const QMetaObject KPIM::ProgressManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KPIM__ProgressManager.data,
      qt_meta_data_KPIM__ProgressManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::ProgressManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::ProgressManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__ProgressManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KPIM::ProgressManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void KPIM::ProgressManager::progressItemAdded(KPIM::ProgressItem * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KPIM::ProgressManager::progressItemProgress(KPIM::ProgressItem * _t1, unsigned int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KPIM::ProgressManager::progressItemCompleted(KPIM::ProgressItem * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KPIM::ProgressManager::progressItemCanceled(KPIM::ProgressItem * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KPIM::ProgressManager::progressItemStatus(KPIM::ProgressItem * _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KPIM::ProgressManager::progressItemLabel(KPIM::ProgressItem * _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KPIM::ProgressManager::progressItemCryptoStatus(KPIM::ProgressItem * _t1, KPIM::ProgressItem::CryptoStatus _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KPIM::ProgressManager::progressItemUsesBusyIndicator(KPIM::ProgressItem * _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KPIM::ProgressManager::showProgressDialog()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
