/****************************************************************************
** Meta object code from reading C++ file 'addresseelineedit.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepimakonadi/addressline/addresslineedit/addresseelineedit.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'addresseelineedit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KPIM__AddresseeLineEdit_t {
    QByteArrayData data[16];
    char stringdata0[184];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__AddresseeLineEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__AddresseeLineEdit_t qt_meta_stringdata_KPIM__AddresseeLineEdit = {
    {
QT_MOC_LITERAL(0, 0, 23), // "KPIM::AddresseeLineEdit"
QT_MOC_LITERAL(1, 24, 13), // "textCompleted"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 10), // "addAddress"
QT_MOC_LITERAL(4, 50, 7), // "address"
QT_MOC_LITERAL(5, 58, 11), // "iconClicked"
QT_MOC_LITERAL(6, 70, 11), // "cursorAtEnd"
QT_MOC_LITERAL(7, 82, 16), // "enableCompletion"
QT_MOC_LITERAL(8, 99, 6), // "enable"
QT_MOC_LITERAL(9, 106, 7), // "setText"
QT_MOC_LITERAL(10, 114, 4), // "text"
QT_MOC_LITERAL(11, 119, 12), // "expandGroups"
QT_MOC_LITERAL(12, 132, 19), // "slotEditingFinished"
QT_MOC_LITERAL(13, 152, 21), // "slotGroupSearchResult"
QT_MOC_LITERAL(14, 174, 5), // "KJob*"
QT_MOC_LITERAL(15, 180, 3) // "job"

    },
    "KPIM::AddresseeLineEdit\0textCompleted\0"
    "\0addAddress\0address\0iconClicked\0"
    "cursorAtEnd\0enableCompletion\0enable\0"
    "setText\0text\0expandGroups\0slotEditingFinished\0"
    "slotGroupSearchResult\0KJob*\0job"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__AddresseeLineEdit[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    1,   60,    2, 0x06 /* Public */,
       5,    0,   63,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,   64,    2, 0x0a /* Public */,
       7,    1,   65,    2, 0x0a /* Public */,
       9,    1,   68,    2, 0x0a /* Public */,
      11,    0,   71,    2, 0x0a /* Public */,
      12,    0,   72,    2, 0x0a /* Public */,
      13,    1,   73,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,   15,

       0        // eod
};

void KPIM::AddresseeLineEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AddresseeLineEdit *_t = static_cast<AddresseeLineEdit *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->textCompleted(); break;
        case 1: _t->addAddress((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->iconClicked(); break;
        case 3: _t->cursorAtEnd(); break;
        case 4: _t->enableCompletion((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->setText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->expandGroups(); break;
        case 7: _t->slotEditingFinished(); break;
        case 8: _t->slotGroupSearchResult((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (AddresseeLineEdit::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AddresseeLineEdit::textCompleted)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (AddresseeLineEdit::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AddresseeLineEdit::addAddress)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (AddresseeLineEdit::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AddresseeLineEdit::iconClicked)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KPIM::AddresseeLineEdit::staticMetaObject = {
    { &KLineEdit::staticMetaObject, qt_meta_stringdata_KPIM__AddresseeLineEdit.data,
      qt_meta_data_KPIM__AddresseeLineEdit,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::AddresseeLineEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::AddresseeLineEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__AddresseeLineEdit.stringdata0))
        return static_cast<void*>(this);
    return KLineEdit::qt_metacast(_clname);
}

int KPIM::AddresseeLineEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KLineEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KPIM::AddresseeLineEdit::textCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KPIM::AddresseeLineEdit::addAddress(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KPIM::AddresseeLineEdit::iconClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
