/****************************************************************************
** Meta object code from reading C++ file 'statusbarprogresswidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepim/progresswidget/statusbarprogresswidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'statusbarprogresswidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KPIM__StatusbarProgressWidget_t {
    QByteArrayData data[14];
    char stringdata0[247];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__StatusbarProgressWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__StatusbarProgressWidget_t qt_meta_stringdata_KPIM__StatusbarProgressWidget = {
    {
QT_MOC_LITERAL(0, 0, 29), // "KPIM::StatusbarProgressWidget"
QT_MOC_LITERAL(1, 30, 9), // "slotClean"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 21), // "slotProgressItemAdded"
QT_MOC_LITERAL(4, 63, 19), // "KPIM::ProgressItem*"
QT_MOC_LITERAL(5, 83, 1), // "i"
QT_MOC_LITERAL(6, 85, 25), // "slotProgressItemCompleted"
QT_MOC_LITERAL(7, 111, 24), // "slotProgressItemProgress"
QT_MOC_LITERAL(8, 136, 5), // "value"
QT_MOC_LITERAL(9, 142, 25), // "slotProgressButtonClicked"
QT_MOC_LITERAL(10, 168, 25), // "slotProgressDialogVisible"
QT_MOC_LITERAL(11, 194, 19), // "slotShowItemDelayed"
QT_MOC_LITERAL(12, 214, 17), // "slotBusyIndicator"
QT_MOC_LITERAL(13, 232, 14) // "updateBusyMode"

    },
    "KPIM::StatusbarProgressWidget\0slotClean\0"
    "\0slotProgressItemAdded\0KPIM::ProgressItem*\0"
    "i\0slotProgressItemCompleted\0"
    "slotProgressItemProgress\0value\0"
    "slotProgressButtonClicked\0"
    "slotProgressDialogVisible\0slotShowItemDelayed\0"
    "slotBusyIndicator\0updateBusyMode"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__StatusbarProgressWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x0a /* Public */,
       3,    1,   60,    2, 0x0a /* Public */,
       6,    1,   63,    2, 0x0a /* Public */,
       7,    2,   66,    2, 0x0a /* Public */,
       9,    0,   71,    2, 0x0a /* Public */,
      10,    1,   72,    2, 0x09 /* Protected */,
      11,    0,   75,    2, 0x09 /* Protected */,
      12,    0,   76,    2, 0x09 /* Protected */,
      13,    1,   77,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 4, QMetaType::UInt,    5,    8,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,

       0        // eod
};

void KPIM::StatusbarProgressWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        StatusbarProgressWidget *_t = static_cast<StatusbarProgressWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotClean(); break;
        case 1: _t->slotProgressItemAdded((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        case 2: _t->slotProgressItemCompleted((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        case 3: _t->slotProgressItemProgress((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 4: _t->slotProgressButtonClicked(); break;
        case 5: _t->slotProgressDialogVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->slotShowItemDelayed(); break;
        case 7: _t->slotBusyIndicator(); break;
        case 8: _t->updateBusyMode((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KPIM::StatusbarProgressWidget::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_KPIM__StatusbarProgressWidget.data,
      qt_meta_data_KPIM__StatusbarProgressWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::StatusbarProgressWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::StatusbarProgressWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__StatusbarProgressWidget.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int KPIM::StatusbarProgressWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
