/****************************************************************************
** Meta object code from reading C++ file 'addresseelineedit_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepimakonadi/addressline/addresslineedit/addresseelineedit_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'addresseelineedit_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KPIM__AddresseeLineEditPrivate_t {
    QByteArrayData data[21];
    char stringdata0[407];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__AddresseeLineEditPrivate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__AddresseeLineEditPrivate_t qt_meta_stringdata_KPIM__AddresseeLineEditPrivate = {
    {
QT_MOC_LITERAL(0, 0, 30), // "KPIM::AddresseeLineEditPrivate"
QT_MOC_LITERAL(1, 31, 22), // "slotToggleExpandGroups"
QT_MOC_LITERAL(2, 54, 0), // ""
QT_MOC_LITERAL(3, 55, 17), // "slotShowOUChanged"
QT_MOC_LITERAL(4, 73, 14), // "slotCompletion"
QT_MOC_LITERAL(5, 88, 19), // "slotPopupCompletion"
QT_MOC_LITERAL(6, 108, 17), // "slotReturnPressed"
QT_MOC_LITERAL(7, 126, 19), // "slotStartLDAPLookup"
QT_MOC_LITERAL(8, 146, 18), // "slotLDAPSearchData"
QT_MOC_LITERAL(9, 165, 23), // "KLDAP::LdapResult::List"
QT_MOC_LITERAL(10, 189, 23), // "slotEditCompletionOrder"
QT_MOC_LITERAL(11, 213, 17), // "slotUserCancelled"
QT_MOC_LITERAL(12, 231, 22), // "slotAkonadiHandleItems"
QT_MOC_LITERAL(13, 254, 19), // "Akonadi::Item::List"
QT_MOC_LITERAL(14, 274, 5), // "items"
QT_MOC_LITERAL(15, 280, 23), // "slotAkonadiSearchResult"
QT_MOC_LITERAL(16, 304, 5), // "KJob*"
QT_MOC_LITERAL(17, 310, 30), // "slotAkonadiCollectionsReceived"
QT_MOC_LITERAL(18, 341, 25), // "Akonadi::Collection::List"
QT_MOC_LITERAL(19, 367, 13), // "searchInBaloo"
QT_MOC_LITERAL(20, 381, 25) // "slotTriggerDelayedQueries"

    },
    "KPIM::AddresseeLineEditPrivate\0"
    "slotToggleExpandGroups\0\0slotShowOUChanged\0"
    "slotCompletion\0slotPopupCompletion\0"
    "slotReturnPressed\0slotStartLDAPLookup\0"
    "slotLDAPSearchData\0KLDAP::LdapResult::List\0"
    "slotEditCompletionOrder\0slotUserCancelled\0"
    "slotAkonadiHandleItems\0Akonadi::Item::List\0"
    "items\0slotAkonadiSearchResult\0KJob*\0"
    "slotAkonadiCollectionsReceived\0"
    "Akonadi::Collection::List\0searchInBaloo\0"
    "slotTriggerDelayedQueries"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__AddresseeLineEditPrivate[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x0a /* Public */,
       3,    1,   87,    2, 0x0a /* Public */,
       4,    0,   90,    2, 0x08 /* Private */,
       5,    1,   91,    2, 0x08 /* Private */,
       6,    1,   94,    2, 0x08 /* Private */,
       7,    0,   97,    2, 0x08 /* Private */,
       8,    1,   98,    2, 0x08 /* Private */,
      10,    0,  101,    2, 0x08 /* Private */,
      11,    1,  102,    2, 0x08 /* Private */,
      12,    1,  105,    2, 0x08 /* Private */,
      15,    1,  108,    2, 0x08 /* Private */,
      17,    1,  111,    2, 0x08 /* Private */,
      19,    0,  114,    2, 0x08 /* Private */,
      20,    0,  115,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, 0x80000000 | 18,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KPIM::AddresseeLineEditPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AddresseeLineEditPrivate *_t = static_cast<AddresseeLineEditPrivate *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotToggleExpandGroups((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->slotShowOUChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->slotCompletion(); break;
        case 3: _t->slotPopupCompletion((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->slotReturnPressed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->slotStartLDAPLookup(); break;
        case 6: _t->slotLDAPSearchData((*reinterpret_cast< const KLDAP::LdapResult::List(*)>(_a[1]))); break;
        case 7: _t->slotEditCompletionOrder(); break;
        case 8: _t->slotUserCancelled((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->slotAkonadiHandleItems((*reinterpret_cast< const Akonadi::Item::List(*)>(_a[1]))); break;
        case 10: _t->slotAkonadiSearchResult((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 11: _t->slotAkonadiCollectionsReceived((*reinterpret_cast< const Akonadi::Collection::List(*)>(_a[1]))); break;
        case 12: _t->searchInBaloo(); break;
        case 13: _t->slotTriggerDelayedQueries(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item::List >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Collection::List >(); break;
            }
            break;
        }
    }
}

const QMetaObject KPIM::AddresseeLineEditPrivate::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KPIM__AddresseeLineEditPrivate.data,
      qt_meta_data_KPIM__AddresseeLineEditPrivate,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::AddresseeLineEditPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::AddresseeLineEditPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__AddresseeLineEditPrivate.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KPIM::AddresseeLineEditPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
