/****************************************************************************
** Meta object code from reading C++ file 'multiplyinglineview_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepim/multiplyingline/multiplyinglineview_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'multiplyinglineview_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KPIM__MultiplyingLineView_t {
    QByteArrayData data[25];
    char stringdata0[360];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__MultiplyingLineView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__MultiplyingLineView_t qt_meta_stringdata_KPIM__MultiplyingLineView = {
    {
QT_MOC_LITERAL(0, 0, 25), // "KPIM::MultiplyingLineView"
QT_MOC_LITERAL(1, 26, 7), // "focusUp"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 9), // "focusDown"
QT_MOC_LITERAL(4, 45, 10), // "focusRight"
QT_MOC_LITERAL(5, 56, 21), // "completionModeChanged"
QT_MOC_LITERAL(6, 78, 27), // "KCompletion::CompletionMode"
QT_MOC_LITERAL(7, 106, 15), // "sizeHintChanged"
QT_MOC_LITERAL(8, 122, 11), // "lineDeleted"
QT_MOC_LITERAL(9, 134, 3), // "pos"
QT_MOC_LITERAL(10, 138, 9), // "lineAdded"
QT_MOC_LITERAL(11, 148, 22), // "KPIM::MultiplyingLine*"
QT_MOC_LITERAL(12, 171, 17), // "setCompletionMode"
QT_MOC_LITERAL(13, 189, 4), // "mode"
QT_MOC_LITERAL(14, 194, 7), // "addLine"
QT_MOC_LITERAL(15, 202, 16), // "MultiplyingLine*"
QT_MOC_LITERAL(16, 219, 8), // "setFocus"
QT_MOC_LITERAL(17, 228, 11), // "setFocusTop"
QT_MOC_LITERAL(18, 240, 14), // "setFocusBottom"
QT_MOC_LITERAL(19, 255, 17), // "slotReturnPressed"
QT_MOC_LITERAL(20, 273, 15), // "slotDownPressed"
QT_MOC_LITERAL(21, 289, 13), // "slotUpPressed"
QT_MOC_LITERAL(22, 303, 22), // "slotDecideLineDeletion"
QT_MOC_LITERAL(23, 326, 14), // "slotDeleteLine"
QT_MOC_LITERAL(24, 341, 18) // "moveScrollBarToEnd"

    },
    "KPIM::MultiplyingLineView\0focusUp\0\0"
    "focusDown\0focusRight\0completionModeChanged\0"
    "KCompletion::CompletionMode\0sizeHintChanged\0"
    "lineDeleted\0pos\0lineAdded\0"
    "KPIM::MultiplyingLine*\0setCompletionMode\0"
    "mode\0addLine\0MultiplyingLine*\0setFocus\0"
    "setFocusTop\0setFocusBottom\0slotReturnPressed\0"
    "slotDownPressed\0slotUpPressed\0"
    "slotDecideLineDeletion\0slotDeleteLine\0"
    "moveScrollBarToEnd"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__MultiplyingLineView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  104,    2, 0x06 /* Public */,
       3,    0,  105,    2, 0x06 /* Public */,
       4,    0,  106,    2, 0x06 /* Public */,
       5,    1,  107,    2, 0x06 /* Public */,
       7,    0,  110,    2, 0x06 /* Public */,
       8,    1,  111,    2, 0x06 /* Public */,
      10,    1,  114,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    1,  117,    2, 0x0a /* Public */,
      14,    0,  120,    2, 0x0a /* Public */,
      16,    0,  121,    2, 0x0a /* Public */,
      17,    0,  122,    2, 0x0a /* Public */,
      18,    0,  123,    2, 0x0a /* Public */,
      19,    1,  124,    2, 0x09 /* Protected */,
      20,    1,  127,    2, 0x09 /* Protected */,
      21,    1,  130,    2, 0x09 /* Protected */,
      22,    1,  133,    2, 0x09 /* Protected */,
      23,    0,  136,    2, 0x09 /* Protected */,
      24,    0,  137,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, 0x80000000 | 11,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,   13,
    0x80000000 | 15,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,    2,
    QMetaType::Void, 0x80000000 | 11,    2,
    QMetaType::Void, 0x80000000 | 11,    2,
    QMetaType::Void, 0x80000000 | 11,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KPIM::MultiplyingLineView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MultiplyingLineView *_t = static_cast<MultiplyingLineView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->focusUp(); break;
        case 1: _t->focusDown(); break;
        case 2: _t->focusRight(); break;
        case 3: _t->completionModeChanged((*reinterpret_cast< KCompletion::CompletionMode(*)>(_a[1]))); break;
        case 4: _t->sizeHintChanged(); break;
        case 5: _t->lineDeleted((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->lineAdded((*reinterpret_cast< KPIM::MultiplyingLine*(*)>(_a[1]))); break;
        case 7: _t->setCompletionMode((*reinterpret_cast< KCompletion::CompletionMode(*)>(_a[1]))); break;
        case 8: { MultiplyingLine* _r = _t->addLine();
            if (_a[0]) *reinterpret_cast< MultiplyingLine**>(_a[0]) = std::move(_r); }  break;
        case 9: _t->setFocus(); break;
        case 10: _t->setFocusTop(); break;
        case 11: _t->setFocusBottom(); break;
        case 12: _t->slotReturnPressed((*reinterpret_cast< KPIM::MultiplyingLine*(*)>(_a[1]))); break;
        case 13: _t->slotDownPressed((*reinterpret_cast< KPIM::MultiplyingLine*(*)>(_a[1]))); break;
        case 14: _t->slotUpPressed((*reinterpret_cast< KPIM::MultiplyingLine*(*)>(_a[1]))); break;
        case 15: _t->slotDecideLineDeletion((*reinterpret_cast< KPIM::MultiplyingLine*(*)>(_a[1]))); break;
        case 16: _t->slotDeleteLine(); break;
        case 17: _t->moveScrollBarToEnd(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (MultiplyingLineView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLineView::focusUp)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (MultiplyingLineView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLineView::focusDown)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (MultiplyingLineView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLineView::focusRight)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (MultiplyingLineView::*_t)(KCompletion::CompletionMode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLineView::completionModeChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (MultiplyingLineView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLineView::sizeHintChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (MultiplyingLineView::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLineView::lineDeleted)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (MultiplyingLineView::*_t)(KPIM::MultiplyingLine * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLineView::lineAdded)) {
                *result = 6;
                return;
            }
        }
    }
}

const QMetaObject KPIM::MultiplyingLineView::staticMetaObject = {
    { &QScrollArea::staticMetaObject, qt_meta_stringdata_KPIM__MultiplyingLineView.data,
      qt_meta_data_KPIM__MultiplyingLineView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::MultiplyingLineView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::MultiplyingLineView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__MultiplyingLineView.stringdata0))
        return static_cast<void*>(this);
    return QScrollArea::qt_metacast(_clname);
}

int KPIM::MultiplyingLineView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void KPIM::MultiplyingLineView::focusUp()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KPIM::MultiplyingLineView::focusDown()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KPIM::MultiplyingLineView::focusRight()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KPIM::MultiplyingLineView::completionModeChanged(KCompletion::CompletionMode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KPIM::MultiplyingLineView::sizeHintChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KPIM::MultiplyingLineView::lineDeleted(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KPIM::MultiplyingLineView::lineAdded(KPIM::MultiplyingLine * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
