/****************************************************************************
** Meta object code from reading C++ file 'ldapclientsearch.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepim/ldap/ldapclientsearch.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ldapclientsearch.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KLDAP__LdapClientSearch_t {
    QByteArrayData data[10];
    char stringdata0[160];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KLDAP__LdapClientSearch_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KLDAP__LdapClientSearch_t qt_meta_stringdata_KLDAP__LdapClientSearch = {
    {
QT_MOC_LITERAL(0, 0, 23), // "KLDAP::LdapClientSearch"
QT_MOC_LITERAL(1, 24, 10), // "searchData"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 7), // "results"
QT_MOC_LITERAL(4, 44, 23), // "KLDAP::LdapResult::List"
QT_MOC_LITERAL(5, 68, 29), // "KLDAP::LdapResultObject::List"
QT_MOC_LITERAL(6, 98, 10), // "searchDone"
QT_MOC_LITERAL(7, 109, 14), // "slotLDAPResult"
QT_MOC_LITERAL(8, 124, 17), // "KLDAP::LdapClient"
QT_MOC_LITERAL(9, 142, 17) // "KLDAP::LdapObject"

    },
    "KLDAP::LdapClientSearch\0searchData\0\0"
    "results\0KLDAP::LdapResult::List\0"
    "KLDAP::LdapResultObject::List\0searchDone\0"
    "slotLDAPResult\0KLDAP::LdapClient\0"
    "KLDAP::LdapObject"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KLDAP__LdapClientSearch[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,
       1,    1,   42,    2, 0x06 /* Public */,
       1,    1,   45,    2, 0x06 /* Public */,
       6,    0,   48,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    2,   49,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QStringList,    3,
    QMetaType::Void, 0x80000000 | 4,    3,
    QMetaType::Void, 0x80000000 | 5,    3,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 8, 0x80000000 | 9,    2,    2,

       0        // eod
};

void KLDAP::LdapClientSearch::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        LdapClientSearch *_t = static_cast<LdapClientSearch *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->searchData((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 1: _t->searchData((*reinterpret_cast< const KLDAP::LdapResult::List(*)>(_a[1]))); break;
        case 2: _t->searchData((*reinterpret_cast< const KLDAP::LdapResultObject::List(*)>(_a[1]))); break;
        case 3: _t->searchDone(); break;
        case 4: _t->d->slotLDAPResult((*reinterpret_cast< const KLDAP::LdapClient(*)>(_a[1])),(*reinterpret_cast< const KLDAP::LdapObject(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (LdapClientSearch::*_t)(const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LdapClientSearch::searchData)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (LdapClientSearch::*_t)(const KLDAP::LdapResult::List & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LdapClientSearch::searchData)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (LdapClientSearch::*_t)(const KLDAP::LdapResultObject::List & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LdapClientSearch::searchData)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (LdapClientSearch::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LdapClientSearch::searchDone)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject KLDAP::LdapClientSearch::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KLDAP__LdapClientSearch.data,
      qt_meta_data_KLDAP__LdapClientSearch,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KLDAP::LdapClientSearch::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KLDAP::LdapClientSearch::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KLDAP__LdapClientSearch.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KLDAP::LdapClientSearch::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KLDAP::LdapClientSearch::searchData(const QStringList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KLDAP::LdapClientSearch::searchData(const KLDAP::LdapResult::List & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KLDAP::LdapClientSearch::searchData(const KLDAP::LdapResultObject::List & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KLDAP::LdapClientSearch::searchDone()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
