/****************************************************************************
** Meta object code from reading C++ file 'kcheckcombobox.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepim/widgets/kcheckcombobox.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcheckcombobox.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KPIM__KCheckComboBox_t {
    QByteArrayData data[10];
    char stringdata0[116];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KCheckComboBox_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KCheckComboBox_t qt_meta_stringdata_KPIM__KCheckComboBox = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KPIM::KCheckComboBox"
QT_MOC_LITERAL(1, 21, 19), // "checkedItemsChanged"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 5), // "items"
QT_MOC_LITERAL(4, 48, 15), // "setCheckedItems"
QT_MOC_LITERAL(5, 64, 4), // "role"
QT_MOC_LITERAL(6, 69, 9), // "separator"
QT_MOC_LITERAL(7, 79, 11), // "defaultText"
QT_MOC_LITERAL(8, 91, 11), // "squeezeText"
QT_MOC_LITERAL(9, 103, 12) // "checkedItems"

    },
    "KPIM::KCheckComboBox\0checkedItemsChanged\0"
    "\0items\0setCheckedItems\0role\0separator\0"
    "defaultText\0squeezeText\0checkedItems"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KCheckComboBox[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       4,   40, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    2,   32,    2, 0x0a /* Public */,
       4,    1,   37,    2, 0x2a /* Public | MethodCloned */,

 // signals: parameters
    QMetaType::Void, QMetaType::QStringList,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::QStringList, QMetaType::Int,    3,    5,
    QMetaType::Void, QMetaType::QStringList,    3,

 // properties: name, type, flags
       6, QMetaType::QString, 0x00095103,
       7, QMetaType::QString, 0x00095103,
       8, QMetaType::Bool, 0x00095103,
       9, QMetaType::QStringList, 0x00095103,

       0        // eod
};

void KPIM::KCheckComboBox::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KCheckComboBox *_t = static_cast<KCheckComboBox *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->checkedItemsChanged((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 1: _t->setCheckedItems((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->setCheckedItems((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KCheckComboBox::*_t)(const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KCheckComboBox::checkedItemsChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KCheckComboBox *_t = static_cast<KCheckComboBox *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->separator(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->defaultText(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->squeezeText(); break;
        case 3: *reinterpret_cast< QStringList*>(_v) = _t->checkedItems(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KCheckComboBox *_t = static_cast<KCheckComboBox *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSeparator(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setDefaultText(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setSqueezeText(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setCheckedItems(*reinterpret_cast< QStringList*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KPIM::KCheckComboBox::staticMetaObject = {
    { &KComboBox::staticMetaObject, qt_meta_stringdata_KPIM__KCheckComboBox.data,
      qt_meta_data_KPIM__KCheckComboBox,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KCheckComboBox::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KCheckComboBox::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KCheckComboBox.stringdata0))
        return static_cast<void*>(this);
    return KComboBox::qt_metacast(_clname);
}

int KPIM::KCheckComboBox::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KComboBox::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 4;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KPIM::KCheckComboBox::checkedItemsChanged(const QStringList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
