/****************************************************************************
** Meta object code from reading C++ file 'ldapsearchdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepim/ldap/ldapsearchdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ldapsearchdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KLDAP__LdapSearchDialog_t {
    QByteArrayData data[15];
    char stringdata0[227];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KLDAP__LdapSearchDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KLDAP__LdapSearchDialog_t qt_meta_stringdata_KLDAP__LdapSearchDialog = {
    {
QT_MOC_LITERAL(0, 0, 23), // "KLDAP::LdapSearchDialog"
QT_MOC_LITERAL(1, 24, 13), // "contactsAdded"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 9), // "slotUser1"
QT_MOC_LITERAL(4, 49, 9), // "slotUser2"
QT_MOC_LITERAL(5, 59, 30), // "slotCustomContextMenuRequested"
QT_MOC_LITERAL(6, 90, 17), // "slotCancelClicked"
QT_MOC_LITERAL(7, 108, 13), // "slotAddResult"
QT_MOC_LITERAL(8, 122, 17), // "KLDAP::LdapClient"
QT_MOC_LITERAL(9, 140, 17), // "KLDAP::LdapObject"
QT_MOC_LITERAL(10, 158, 12), // "slotSetScope"
QT_MOC_LITERAL(11, 171, 15), // "slotStartSearch"
QT_MOC_LITERAL(12, 187, 14), // "slotStopSearch"
QT_MOC_LITERAL(13, 202, 14), // "slotSearchDone"
QT_MOC_LITERAL(14, 217, 9) // "slotError"

    },
    "KLDAP::LdapSearchDialog\0contactsAdded\0"
    "\0slotUser1\0slotUser2\0"
    "slotCustomContextMenuRequested\0"
    "slotCancelClicked\0slotAddResult\0"
    "KLDAP::LdapClient\0KLDAP::LdapObject\0"
    "slotSetScope\0slotStartSearch\0"
    "slotStopSearch\0slotSearchDone\0slotError"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KLDAP__LdapSearchDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   70,    2, 0x09 /* Protected */,
       4,    0,   71,    2, 0x09 /* Protected */,
       5,    1,   72,    2, 0x09 /* Protected */,
       6,    0,   75,    2, 0x09 /* Protected */,
       7,    2,   76,    2, 0x08 /* Private */,
      10,    1,   81,    2, 0x08 /* Private */,
      11,    0,   84,    2, 0x08 /* Private */,
      12,    0,   85,    2, 0x08 /* Private */,
      13,    0,   86,    2, 0x08 /* Private */,
      14,    1,   87,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8, 0x80000000 | 9,    2,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void KLDAP::LdapSearchDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        LdapSearchDialog *_t = static_cast<LdapSearchDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->contactsAdded(); break;
        case 1: _t->slotUser1(); break;
        case 2: _t->slotUser2(); break;
        case 3: _t->slotCustomContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 4: _t->slotCancelClicked(); break;
        case 5: _t->d->slotAddResult((*reinterpret_cast< const KLDAP::LdapClient(*)>(_a[1])),(*reinterpret_cast< const KLDAP::LdapObject(*)>(_a[2]))); break;
        case 6: _t->d->slotSetScope((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->d->slotStartSearch(); break;
        case 8: _t->d->slotStopSearch(); break;
        case 9: _t->d->slotSearchDone(); break;
        case 10: _t->d->slotError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (LdapSearchDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LdapSearchDialog::contactsAdded)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KLDAP::LdapSearchDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_KLDAP__LdapSearchDialog.data,
      qt_meta_data_KLDAP__LdapSearchDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KLDAP::LdapSearchDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KLDAP::LdapSearchDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KLDAP__LdapSearchDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int KLDAP::LdapSearchDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KLDAP::LdapSearchDialog::contactsAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
