/****************************************************************************
** Meta object code from reading C++ file 'kprefsdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepim/prefs/kprefsdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kprefsdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KPIM__KPrefsWid_t {
    QByteArrayData data[3];
    char stringdata0[25];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsWid_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsWid_t qt_meta_stringdata_KPIM__KPrefsWid = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KPIM::KPrefsWid"
QT_MOC_LITERAL(1, 16, 7), // "changed"
QT_MOC_LITERAL(2, 24, 0) // ""

    },
    "KPIM::KPrefsWid\0changed\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsWid[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

       0        // eod
};

void KPIM::KPrefsWid::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KPrefsWid *_t = static_cast<KPrefsWid *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->changed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KPrefsWid::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KPrefsWid::changed)) {
                *result = 0;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsWid::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsWid.data,
      qt_meta_data_KPIM__KPrefsWid,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsWid::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsWid::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsWid.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KPIM::KPrefsWid::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KPIM::KPrefsWid::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_KPIM__KPrefsWidBool_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsWidBool_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsWidBool_t qt_meta_stringdata_KPIM__KPrefsWidBool = {
    {
QT_MOC_LITERAL(0, 0, 19) // "KPIM::KPrefsWidBool"

    },
    "KPIM::KPrefsWidBool"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsWidBool[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KPIM::KPrefsWidBool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsWidBool::staticMetaObject = {
    { &KPrefsWid::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsWidBool.data,
      qt_meta_data_KPIM__KPrefsWidBool,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsWidBool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsWidBool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsWidBool.stringdata0))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int KPIM::KPrefsWidBool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KPIM__KPrefsWidInt_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsWidInt_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsWidInt_t qt_meta_stringdata_KPIM__KPrefsWidInt = {
    {
QT_MOC_LITERAL(0, 0, 18) // "KPIM::KPrefsWidInt"

    },
    "KPIM::KPrefsWidInt"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsWidInt[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KPIM::KPrefsWidInt::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsWidInt::staticMetaObject = {
    { &KPrefsWid::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsWidInt.data,
      qt_meta_data_KPIM__KPrefsWidInt,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsWidInt::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsWidInt::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsWidInt.stringdata0))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int KPIM::KPrefsWidInt::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KPIM__KPrefsWidTime_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsWidTime_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsWidTime_t qt_meta_stringdata_KPIM__KPrefsWidTime = {
    {
QT_MOC_LITERAL(0, 0, 19) // "KPIM::KPrefsWidTime"

    },
    "KPIM::KPrefsWidTime"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsWidTime[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KPIM::KPrefsWidTime::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsWidTime::staticMetaObject = {
    { &KPrefsWid::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsWidTime.data,
      qt_meta_data_KPIM__KPrefsWidTime,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsWidTime::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsWidTime::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsWidTime.stringdata0))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int KPIM::KPrefsWidTime::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KPIM__KPrefsWidDuration_t {
    QByteArrayData data[1];
    char stringdata0[24];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsWidDuration_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsWidDuration_t qt_meta_stringdata_KPIM__KPrefsWidDuration = {
    {
QT_MOC_LITERAL(0, 0, 23) // "KPIM::KPrefsWidDuration"

    },
    "KPIM::KPrefsWidDuration"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsWidDuration[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KPIM::KPrefsWidDuration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsWidDuration::staticMetaObject = {
    { &KPrefsWid::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsWidDuration.data,
      qt_meta_data_KPIM__KPrefsWidDuration,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsWidDuration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsWidDuration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsWidDuration.stringdata0))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int KPIM::KPrefsWidDuration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KPIM__KPrefsWidDate_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsWidDate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsWidDate_t qt_meta_stringdata_KPIM__KPrefsWidDate = {
    {
QT_MOC_LITERAL(0, 0, 19) // "KPIM::KPrefsWidDate"

    },
    "KPIM::KPrefsWidDate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsWidDate[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KPIM::KPrefsWidDate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsWidDate::staticMetaObject = {
    { &KPrefsWid::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsWidDate.data,
      qt_meta_data_KPIM__KPrefsWidDate,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsWidDate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsWidDate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsWidDate.stringdata0))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int KPIM::KPrefsWidDate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KPIM__KPrefsWidColor_t {
    QByteArrayData data[1];
    char stringdata0[21];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsWidColor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsWidColor_t qt_meta_stringdata_KPIM__KPrefsWidColor = {
    {
QT_MOC_LITERAL(0, 0, 20) // "KPIM::KPrefsWidColor"

    },
    "KPIM::KPrefsWidColor"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsWidColor[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KPIM::KPrefsWidColor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsWidColor::staticMetaObject = {
    { &KPrefsWid::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsWidColor.data,
      qt_meta_data_KPIM__KPrefsWidColor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsWidColor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsWidColor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsWidColor.stringdata0))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int KPIM::KPrefsWidColor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KPIM__KPrefsWidFont_t {
    QByteArrayData data[3];
    char stringdata0[32];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsWidFont_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsWidFont_t qt_meta_stringdata_KPIM__KPrefsWidFont = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KPIM::KPrefsWidFont"
QT_MOC_LITERAL(1, 20, 10), // "selectFont"
QT_MOC_LITERAL(2, 31, 0) // ""

    },
    "KPIM::KPrefsWidFont\0selectFont\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsWidFont[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void KPIM::KPrefsWidFont::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KPrefsWidFont *_t = static_cast<KPrefsWidFont *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->selectFont(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsWidFont::staticMetaObject = {
    { &KPrefsWid::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsWidFont.data,
      qt_meta_data_KPIM__KPrefsWidFont,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsWidFont::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsWidFont::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsWidFont.stringdata0))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int KPIM::KPrefsWidFont::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_KPIM__KPrefsWidRadios_t {
    QByteArrayData data[1];
    char stringdata0[22];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsWidRadios_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsWidRadios_t qt_meta_stringdata_KPIM__KPrefsWidRadios = {
    {
QT_MOC_LITERAL(0, 0, 21) // "KPIM::KPrefsWidRadios"

    },
    "KPIM::KPrefsWidRadios"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsWidRadios[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KPIM::KPrefsWidRadios::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsWidRadios::staticMetaObject = {
    { &KPrefsWid::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsWidRadios.data,
      qt_meta_data_KPIM__KPrefsWidRadios,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsWidRadios::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsWidRadios::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsWidRadios.stringdata0))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int KPIM::KPrefsWidRadios::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KPIM__KPrefsWidCombo_t {
    QByteArrayData data[1];
    char stringdata0[21];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsWidCombo_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsWidCombo_t qt_meta_stringdata_KPIM__KPrefsWidCombo = {
    {
QT_MOC_LITERAL(0, 0, 20) // "KPIM::KPrefsWidCombo"

    },
    "KPIM::KPrefsWidCombo"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsWidCombo[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KPIM::KPrefsWidCombo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsWidCombo::staticMetaObject = {
    { &KPrefsWid::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsWidCombo.data,
      qt_meta_data_KPIM__KPrefsWidCombo,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsWidCombo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsWidCombo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsWidCombo.stringdata0))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int KPIM::KPrefsWidCombo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KPIM__KPrefsWidString_t {
    QByteArrayData data[1];
    char stringdata0[22];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsWidString_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsWidString_t qt_meta_stringdata_KPIM__KPrefsWidString = {
    {
QT_MOC_LITERAL(0, 0, 21) // "KPIM::KPrefsWidString"

    },
    "KPIM::KPrefsWidString"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsWidString[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KPIM::KPrefsWidString::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsWidString::staticMetaObject = {
    { &KPrefsWid::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsWidString.data,
      qt_meta_data_KPIM__KPrefsWidString,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsWidString::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsWidString::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsWidString.stringdata0))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int KPIM::KPrefsWidString::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KPIM__KPrefsWidPath_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsWidPath_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsWidPath_t qt_meta_stringdata_KPIM__KPrefsWidPath = {
    {
QT_MOC_LITERAL(0, 0, 19) // "KPIM::KPrefsWidPath"

    },
    "KPIM::KPrefsWidPath"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsWidPath[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KPIM::KPrefsWidPath::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsWidPath::staticMetaObject = {
    { &KPrefsWid::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsWidPath.data,
      qt_meta_data_KPIM__KPrefsWidPath,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsWidPath::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsWidPath::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsWidPath.stringdata0))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int KPIM::KPrefsWidPath::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KPIM__KPrefsDialog_t {
    QByteArrayData data[9];
    char stringdata0[98];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsDialog_t qt_meta_stringdata_KPIM__KPrefsDialog = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KPIM::KPrefsDialog"
QT_MOC_LITERAL(1, 19, 13), // "configChanged"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 11), // "setDefaults"
QT_MOC_LITERAL(4, 46, 10), // "readConfig"
QT_MOC_LITERAL(5, 57, 11), // "writeConfig"
QT_MOC_LITERAL(6, 69, 9), // "slotApply"
QT_MOC_LITERAL(7, 79, 6), // "slotOk"
QT_MOC_LITERAL(8, 86, 11) // "slotDefault"

    },
    "KPIM::KPrefsDialog\0configChanged\0\0"
    "setDefaults\0readConfig\0writeConfig\0"
    "slotApply\0slotOk\0slotDefault"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   50,    2, 0x0a /* Public */,
       4,    0,   51,    2, 0x0a /* Public */,
       5,    0,   52,    2, 0x0a /* Public */,
       6,    0,   53,    2, 0x09 /* Protected */,
       7,    0,   54,    2, 0x09 /* Protected */,
       8,    0,   55,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KPIM::KPrefsDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KPrefsDialog *_t = static_cast<KPrefsDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->configChanged(); break;
        case 1: _t->setDefaults(); break;
        case 2: _t->readConfig(); break;
        case 3: _t->writeConfig(); break;
        case 4: _t->slotApply(); break;
        case 5: _t->slotOk(); break;
        case 6: _t->slotDefault(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KPrefsDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KPrefsDialog::configChanged)) {
                *result = 0;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsDialog::staticMetaObject = {
    { &KPageDialog::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsDialog.data,
      qt_meta_data_KPIM__KPrefsDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsDialog.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KPrefsWidManager"))
        return static_cast< KPrefsWidManager*>(this);
    return KPageDialog::qt_metacast(_clname);
}

int KPIM::KPrefsDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPageDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KPIM::KPrefsDialog::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_KPIM__KPrefsModule_t {
    QByteArrayData data[3];
    char stringdata0[35];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__KPrefsModule_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__KPrefsModule_t qt_meta_stringdata_KPIM__KPrefsModule = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KPIM::KPrefsModule"
QT_MOC_LITERAL(1, 19, 14), // "slotWidChanged"
QT_MOC_LITERAL(2, 34, 0) // ""

    },
    "KPIM::KPrefsModule\0slotWidChanged\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__KPrefsModule[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void KPIM::KPrefsModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KPrefsModule *_t = static_cast<KPrefsModule *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotWidChanged(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject KPIM::KPrefsModule::staticMetaObject = {
    { &KCModule::staticMetaObject, qt_meta_stringdata_KPIM__KPrefsModule.data,
      qt_meta_data_KPIM__KPrefsModule,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::KPrefsModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::KPrefsModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__KPrefsModule.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KPrefsWidManager"))
        return static_cast< KPrefsWidManager*>(this);
    return KCModule::qt_metacast(_clname);
}

int KPIM::KPrefsModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KCModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
