/**
* This file was autogenerated by kgendesignerplugin. Any changes will be lost!
* The generated code in this file is licensed under the same license that the
* input file.
*/
#include <QIcon>
#include <QtDesigner/QDesignerContainerExtension>
#if QT_VERSION >= 0x050500
# include <QtUiPlugin/QDesignerCustomWidgetInterface>
#else
# include <QDesignerCustomWidgetInterface>
#endif
#include <qplugin.h>
#include <qdebug.h>

#include <Libkdepim/KCheckComboBox>


class KPIMKCheckComboBoxPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KPIMKCheckComboBoxPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KPIMKCheckComboBoxPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kpimkcheckcombobox.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Input (KDE-PIM)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("Libkdepim/KCheckComboBox"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KPIM::KCheckComboBox"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Combobox with checkable items (KDE-PIM)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("A combobox that allows the user to check the items in the drop down menu"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KPIM::KCheckComboBox(parent);
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KDEPimWidgets : public QObject, public QDesignerCustomWidgetCollectionInterface
{
    Q_OBJECT
    Q_INTERFACES(QDesignerCustomWidgetCollectionInterface)
       Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QDesignerCustomWidgetInterface")
public:
    KDEPimWidgets(QObject *parent = nullptr);
    virtual ~KDEPimWidgets() {}
    QList<QDesignerCustomWidgetInterface*> customWidgets() const Q_DECL_OVERRIDE { return m_plugins; } 
    
private:
    QList<QDesignerCustomWidgetInterface*> m_plugins;
};

KDEPimWidgets::KDEPimWidgets(QObject *parent)
   : QObject(parent){
                m_plugins.append( new KPIMKCheckComboBoxPlugin(this) );

}

#include </usr/src/extras/kf5-libkdepim/kf5-libkdepim-17.12.3-1.x86_64/build/src/libkdepim/designer/kdepimwidgets.moc>

