/****************************************************************************
** Meta object code from reading C++ file 'multiplyinglineeditor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepim/multiplyingline/multiplyinglineeditor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'multiplyinglineeditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KPIM__MultiplyingLineFactory_t {
    QByteArrayData data[1];
    char stringdata0[29];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__MultiplyingLineFactory_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__MultiplyingLineFactory_t qt_meta_stringdata_KPIM__MultiplyingLineFactory = {
    {
QT_MOC_LITERAL(0, 0, 28) // "KPIM::MultiplyingLineFactory"

    },
    "KPIM::MultiplyingLineFactory"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__MultiplyingLineFactory[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KPIM::MultiplyingLineFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KPIM::MultiplyingLineFactory::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KPIM__MultiplyingLineFactory.data,
      qt_meta_data_KPIM__MultiplyingLineFactory,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::MultiplyingLineFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::MultiplyingLineFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__MultiplyingLineFactory.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KPIM::MultiplyingLineFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KPIM__MultiplyingLineEditor_t {
    QByteArrayData data[16];
    char stringdata0[229];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__MultiplyingLineEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__MultiplyingLineEditor_t qt_meta_stringdata_KPIM__MultiplyingLineEditor = {
    {
QT_MOC_LITERAL(0, 0, 27), // "KPIM::MultiplyingLineEditor"
QT_MOC_LITERAL(1, 28, 7), // "focusUp"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 9), // "focusDown"
QT_MOC_LITERAL(4, 47, 21), // "completionModeChanged"
QT_MOC_LITERAL(5, 69, 27), // "KCompletion::CompletionMode"
QT_MOC_LITERAL(6, 97, 15), // "sizeHintChanged"
QT_MOC_LITERAL(7, 113, 11), // "lineDeleted"
QT_MOC_LITERAL(8, 125, 3), // "pos"
QT_MOC_LITERAL(9, 129, 9), // "lineAdded"
QT_MOC_LITERAL(10, 139, 22), // "KPIM::MultiplyingLine*"
QT_MOC_LITERAL(11, 162, 8), // "setFocus"
QT_MOC_LITERAL(12, 171, 11), // "setFocusTop"
QT_MOC_LITERAL(13, 183, 14), // "setFocusBottom"
QT_MOC_LITERAL(14, 198, 14), // "autoResizeView"
QT_MOC_LITERAL(15, 213, 15) // "dynamicSizeHint"

    },
    "KPIM::MultiplyingLineEditor\0focusUp\0"
    "\0focusDown\0completionModeChanged\0"
    "KCompletion::CompletionMode\0sizeHintChanged\0"
    "lineDeleted\0pos\0lineAdded\0"
    "KPIM::MultiplyingLine*\0setFocus\0"
    "setFocusTop\0setFocusBottom\0autoResizeView\0"
    "dynamicSizeHint"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__MultiplyingLineEditor[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       2,   74, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    0,   60,    2, 0x06 /* Public */,
       4,    1,   61,    2, 0x06 /* Public */,
       6,    0,   64,    2, 0x06 /* Public */,
       7,    1,   65,    2, 0x06 /* Public */,
       9,    1,   68,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,   71,    2, 0x0a /* Public */,
      12,    0,   72,    2, 0x0a /* Public */,
      13,    0,   73,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, 0x80000000 | 10,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      14, QMetaType::Bool, 0x00095103,
      15, QMetaType::Bool, 0x00095103,

       0        // eod
};

void KPIM::MultiplyingLineEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MultiplyingLineEditor *_t = static_cast<MultiplyingLineEditor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->focusUp(); break;
        case 1: _t->focusDown(); break;
        case 2: _t->completionModeChanged((*reinterpret_cast< KCompletion::CompletionMode(*)>(_a[1]))); break;
        case 3: _t->sizeHintChanged(); break;
        case 4: _t->lineDeleted((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->lineAdded((*reinterpret_cast< KPIM::MultiplyingLine*(*)>(_a[1]))); break;
        case 6: _t->setFocus(); break;
        case 7: _t->setFocusTop(); break;
        case 8: _t->setFocusBottom(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (MultiplyingLineEditor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLineEditor::focusUp)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (MultiplyingLineEditor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLineEditor::focusDown)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (MultiplyingLineEditor::*_t)(KCompletion::CompletionMode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLineEditor::completionModeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (MultiplyingLineEditor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLineEditor::sizeHintChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (MultiplyingLineEditor::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLineEditor::lineDeleted)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (MultiplyingLineEditor::*_t)(KPIM::MultiplyingLine * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLineEditor::lineAdded)) {
                *result = 5;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        MultiplyingLineEditor *_t = static_cast<MultiplyingLineEditor *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->autoResizeView(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->dynamicSizeHint(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        MultiplyingLineEditor *_t = static_cast<MultiplyingLineEditor *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAutoResizeView(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setDynamicSizeHint(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KPIM::MultiplyingLineEditor::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KPIM__MultiplyingLineEditor.data,
      qt_meta_data_KPIM__MultiplyingLineEditor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::MultiplyingLineEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::MultiplyingLineEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__MultiplyingLineEditor.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KPIM::MultiplyingLineEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KPIM::MultiplyingLineEditor::focusUp()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KPIM::MultiplyingLineEditor::focusDown()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KPIM::MultiplyingLineEditor::completionModeChanged(KCompletion::CompletionMode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KPIM::MultiplyingLineEditor::sizeHintChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KPIM::MultiplyingLineEditor::lineDeleted(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KPIM::MultiplyingLineEditor::lineAdded(KPIM::MultiplyingLine * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
