/****************************************************************************
** Meta object code from reading C++ file 'multiplyingline.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepim/multiplyingline/multiplyingline.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'multiplyingline.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KPIM__MultiplyingLine_t {
    QByteArrayData data[14];
    char stringdata0[222];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__MultiplyingLine_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__MultiplyingLine_t qt_meta_stringdata_KPIM__MultiplyingLine = {
    {
QT_MOC_LITERAL(0, 0, 21), // "KPIM::MultiplyingLine"
QT_MOC_LITERAL(1, 22, 13), // "returnPressed"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 22), // "KPIM::MultiplyingLine*"
QT_MOC_LITERAL(4, 60, 11), // "downPressed"
QT_MOC_LITERAL(5, 72, 9), // "upPressed"
QT_MOC_LITERAL(6, 82, 12), // "rightPressed"
QT_MOC_LITERAL(7, 95, 10), // "deleteLine"
QT_MOC_LITERAL(8, 106, 21), // "completionModeChanged"
QT_MOC_LITERAL(9, 128, 27), // "KCompletion::CompletionMode"
QT_MOC_LITERAL(10, 156, 21), // "slotPropagateDeletion"
QT_MOC_LITERAL(11, 178, 17), // "slotReturnPressed"
QT_MOC_LITERAL(12, 196, 11), // "slotFocusUp"
QT_MOC_LITERAL(13, 208, 13) // "slotFocusDown"

    },
    "KPIM::MultiplyingLine\0returnPressed\0"
    "\0KPIM::MultiplyingLine*\0downPressed\0"
    "upPressed\0rightPressed\0deleteLine\0"
    "completionModeChanged\0KCompletion::CompletionMode\0"
    "slotPropagateDeletion\0slotReturnPressed\0"
    "slotFocusUp\0slotFocusDown"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__MultiplyingLine[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       4,    1,   67,    2, 0x06 /* Public */,
       5,    1,   70,    2, 0x06 /* Public */,
       6,    0,   73,    2, 0x06 /* Public */,
       7,    1,   74,    2, 0x06 /* Public */,
       8,    1,   77,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    0,   80,    2, 0x0a /* Public */,
      11,    0,   81,    2, 0x09 /* Protected */,
      12,    0,   82,    2, 0x09 /* Protected */,
      13,    0,   83,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 9,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KPIM::MultiplyingLine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MultiplyingLine *_t = static_cast<MultiplyingLine *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->returnPressed((*reinterpret_cast< KPIM::MultiplyingLine*(*)>(_a[1]))); break;
        case 1: _t->downPressed((*reinterpret_cast< KPIM::MultiplyingLine*(*)>(_a[1]))); break;
        case 2: _t->upPressed((*reinterpret_cast< KPIM::MultiplyingLine*(*)>(_a[1]))); break;
        case 3: _t->rightPressed(); break;
        case 4: _t->deleteLine((*reinterpret_cast< KPIM::MultiplyingLine*(*)>(_a[1]))); break;
        case 5: _t->completionModeChanged((*reinterpret_cast< KCompletion::CompletionMode(*)>(_a[1]))); break;
        case 6: _t->slotPropagateDeletion(); break;
        case 7: _t->slotReturnPressed(); break;
        case 8: _t->slotFocusUp(); break;
        case 9: _t->slotFocusDown(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (MultiplyingLine::*_t)(KPIM::MultiplyingLine * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLine::returnPressed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (MultiplyingLine::*_t)(KPIM::MultiplyingLine * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLine::downPressed)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (MultiplyingLine::*_t)(KPIM::MultiplyingLine * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLine::upPressed)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (MultiplyingLine::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLine::rightPressed)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (MultiplyingLine::*_t)(KPIM::MultiplyingLine * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLine::deleteLine)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (MultiplyingLine::*_t)(KCompletion::CompletionMode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiplyingLine::completionModeChanged)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject KPIM::MultiplyingLine::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KPIM__MultiplyingLine.data,
      qt_meta_data_KPIM__MultiplyingLine,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::MultiplyingLine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::MultiplyingLine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__MultiplyingLine.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KPIM::MultiplyingLine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KPIM::MultiplyingLine::returnPressed(KPIM::MultiplyingLine * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KPIM::MultiplyingLine::downPressed(KPIM::MultiplyingLine * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KPIM::MultiplyingLine::upPressed(KPIM::MultiplyingLine * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KPIM::MultiplyingLine::rightPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KPIM::MultiplyingLine::deleteLine(KPIM::MultiplyingLine * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KPIM::MultiplyingLine::completionModeChanged(KCompletion::CompletionMode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
