/****************************************************************************
** Meta object code from reading C++ file 'progressdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepim/progresswidget/progressdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'progressdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KPIM__TransactionItemView_t {
    QByteArrayData data[3];
    char stringdata0[47];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__TransactionItemView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__TransactionItemView_t qt_meta_stringdata_KPIM__TransactionItemView = {
    {
QT_MOC_LITERAL(0, 0, 25), // "KPIM::TransactionItemView"
QT_MOC_LITERAL(1, 26, 19), // "slotLayoutFirstItem"
QT_MOC_LITERAL(2, 46, 0) // ""

    },
    "KPIM::TransactionItemView\0slotLayoutFirstItem\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__TransactionItemView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void KPIM::TransactionItemView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TransactionItemView *_t = static_cast<TransactionItemView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotLayoutFirstItem(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject KPIM::TransactionItemView::staticMetaObject = {
    { &QScrollArea::staticMetaObject, qt_meta_stringdata_KPIM__TransactionItemView.data,
      qt_meta_data_KPIM__TransactionItemView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::TransactionItemView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::TransactionItemView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__TransactionItemView.stringdata0))
        return static_cast<void*>(this);
    return QScrollArea::qt_metacast(_clname);
}

int KPIM::TransactionItemView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_KPIM__TransactionItem_t {
    QByteArrayData data[3];
    char stringdata0[40];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__TransactionItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__TransactionItem_t qt_meta_stringdata_KPIM__TransactionItem = {
    {
QT_MOC_LITERAL(0, 0, 21), // "KPIM::TransactionItem"
QT_MOC_LITERAL(1, 22, 16), // "slotItemCanceled"
QT_MOC_LITERAL(2, 39, 0) // ""

    },
    "KPIM::TransactionItem\0slotItemCanceled\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__TransactionItem[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void KPIM::TransactionItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TransactionItem *_t = static_cast<TransactionItem *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotItemCanceled(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject KPIM::TransactionItem::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KPIM__TransactionItem.data,
      qt_meta_data_KPIM__TransactionItem,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::TransactionItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::TransactionItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__TransactionItem.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KPIM::TransactionItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_KPIM__ProgressDialog_t {
    QByteArrayData data[19];
    char stringdata0[354];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__ProgressDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__ProgressDialog_t qt_meta_stringdata_KPIM__ProgressDialog = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KPIM::ProgressDialog"
QT_MOC_LITERAL(1, 21, 17), // "visibilityChanged"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 20), // "slotToggleVisibility"
QT_MOC_LITERAL(4, 61, 20), // "slotTransactionAdded"
QT_MOC_LITERAL(5, 82, 19), // "KPIM::ProgressItem*"
QT_MOC_LITERAL(6, 102, 4), // "item"
QT_MOC_LITERAL(7, 107, 24), // "slotTransactionCompleted"
QT_MOC_LITERAL(8, 132, 23), // "slotTransactionCanceled"
QT_MOC_LITERAL(9, 156, 23), // "slotTransactionProgress"
QT_MOC_LITERAL(10, 180, 8), // "progress"
QT_MOC_LITERAL(11, 189, 21), // "slotTransactionStatus"
QT_MOC_LITERAL(12, 211, 20), // "slotTransactionLabel"
QT_MOC_LITERAL(13, 232, 27), // "slotTransactionCryptoStatus"
QT_MOC_LITERAL(14, 260, 32), // "KPIM::ProgressItem::CryptoStatus"
QT_MOC_LITERAL(15, 293, 32), // "slotTransactionUsesBusyIndicator"
QT_MOC_LITERAL(16, 326, 9), // "slotClose"
QT_MOC_LITERAL(17, 336, 8), // "slotShow"
QT_MOC_LITERAL(18, 345, 8) // "slotHide"

    },
    "KPIM::ProgressDialog\0visibilityChanged\0"
    "\0slotToggleVisibility\0slotTransactionAdded\0"
    "KPIM::ProgressItem*\0item\0"
    "slotTransactionCompleted\0"
    "slotTransactionCanceled\0slotTransactionProgress\0"
    "progress\0slotTransactionStatus\0"
    "slotTransactionLabel\0slotTransactionCryptoStatus\0"
    "KPIM::ProgressItem::CryptoStatus\0"
    "slotTransactionUsesBusyIndicator\0"
    "slotClose\0slotShow\0slotHide"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__ProgressDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   79,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   82,    2, 0x0a /* Public */,
       4,    1,   83,    2, 0x09 /* Protected */,
       7,    1,   86,    2, 0x09 /* Protected */,
       8,    1,   89,    2, 0x09 /* Protected */,
       9,    2,   92,    2, 0x09 /* Protected */,
      11,    2,   97,    2, 0x09 /* Protected */,
      12,    2,  102,    2, 0x09 /* Protected */,
      13,    2,  107,    2, 0x09 /* Protected */,
      15,    2,  112,    2, 0x09 /* Protected */,
      16,    0,  117,    2, 0x09 /* Protected */,
      17,    0,  118,    2, 0x09 /* Protected */,
      18,    0,  119,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 5, QMetaType::UInt,    6,   10,
    QMetaType::Void, 0x80000000 | 5, QMetaType::QString,    6,    2,
    QMetaType::Void, 0x80000000 | 5, QMetaType::QString,    6,    2,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 14,    6,    2,
    QMetaType::Void, 0x80000000 | 5, QMetaType::Bool,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KPIM::ProgressDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ProgressDialog *_t = static_cast<ProgressDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->visibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->slotToggleVisibility(); break;
        case 2: _t->slotTransactionAdded((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        case 3: _t->slotTransactionCompleted((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        case 4: _t->slotTransactionCanceled((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1]))); break;
        case 5: _t->slotTransactionProgress((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 6: _t->slotTransactionStatus((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 7: _t->slotTransactionLabel((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 8: _t->slotTransactionCryptoStatus((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< KPIM::ProgressItem::CryptoStatus(*)>(_a[2]))); break;
        case 9: _t->slotTransactionUsesBusyIndicator((*reinterpret_cast< KPIM::ProgressItem*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 10: _t->slotClose(); break;
        case 11: _t->slotShow(); break;
        case 12: _t->slotHide(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPIM::ProgressItem* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ProgressDialog::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ProgressDialog::visibilityChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KPIM::ProgressDialog::staticMetaObject = {
    { &OverlayWidget::staticMetaObject, qt_meta_stringdata_KPIM__ProgressDialog.data,
      qt_meta_data_KPIM__ProgressDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::ProgressDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::ProgressDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__ProgressDialog.stringdata0))
        return static_cast<void*>(this);
    return OverlayWidget::qt_metacast(_clname);
}

int KPIM::ProgressDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = OverlayWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void KPIM::ProgressDialog::visibilityChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
