/****************************************************************************
** Meta object code from reading C++ file 'personsearchjob.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepimakonadi/job/personsearchjob.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QVector>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'personsearchjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KPIM__PersonSearchJob_t {
    QByteArrayData data[21];
    char stringdata0[295];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPIM__PersonSearchJob_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPIM__PersonSearchJob_t qt_meta_stringdata_KPIM__PersonSearchJob = {
    {
QT_MOC_LITERAL(0, 0, 21), // "KPIM::PersonSearchJob"
QT_MOC_LITERAL(1, 22, 12), // "personsFound"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 15), // "QVector<Person>"
QT_MOC_LITERAL(4, 52, 7), // "persons"
QT_MOC_LITERAL(5, 60, 12), // "personUpdate"
QT_MOC_LITERAL(6, 73, 6), // "Person"
QT_MOC_LITERAL(7, 80, 6), // "person"
QT_MOC_LITERAL(8, 87, 4), // "kill"
QT_MOC_LITERAL(9, 92, 13), // "KillVerbosity"
QT_MOC_LITERAL(10, 106, 9), // "verbosity"
QT_MOC_LITERAL(11, 116, 21), // "onCollectionsReceived"
QT_MOC_LITERAL(12, 138, 25), // "Akonadi::Collection::List"
QT_MOC_LITERAL(13, 164, 20), // "onCollectionsFetched"
QT_MOC_LITERAL(14, 185, 5), // "KJob*"
QT_MOC_LITERAL(15, 191, 16), // "onLDAPSearchData"
QT_MOC_LITERAL(16, 208, 29), // "KLDAP::LdapResultObject::List"
QT_MOC_LITERAL(17, 238, 16), // "onLDAPSearchDone"
QT_MOC_LITERAL(18, 255, 22), // "updatePersonCollection"
QT_MOC_LITERAL(19, 278, 12), // "modifyResult"
QT_MOC_LITERAL(20, 291, 3) // "job"

    },
    "KPIM::PersonSearchJob\0personsFound\0\0"
    "QVector<Person>\0persons\0personUpdate\0"
    "Person\0person\0kill\0KillVerbosity\0"
    "verbosity\0onCollectionsReceived\0"
    "Akonadi::Collection::List\0"
    "onCollectionsFetched\0KJob*\0onLDAPSearchData\0"
    "KLDAP::LdapResultObject::List\0"
    "onLDAPSearchDone\0updatePersonCollection\0"
    "modifyResult\0job"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPIM__PersonSearchJob[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       5,    1,   67,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,   70,    2, 0x0a /* Public */,
       8,    0,   73,    2, 0x2a /* Public | MethodCloned */,
      11,    1,   74,    2, 0x08 /* Private */,
      13,    1,   77,    2, 0x08 /* Private */,
      15,    1,   80,    2, 0x08 /* Private */,
      17,    0,   83,    2, 0x08 /* Private */,
      18,    1,   84,    2, 0x08 /* Private */,
      19,    1,   87,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,

 // slots: parameters
    QMetaType::Bool, 0x80000000 | 9,   10,
    QMetaType::Bool,
    QMetaType::Void, 0x80000000 | 12,    2,
    QMetaType::Void, 0x80000000 | 14,    2,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 14,   20,

       0        // eod
};

void KPIM::PersonSearchJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PersonSearchJob *_t = static_cast<PersonSearchJob *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->personsFound((*reinterpret_cast< const QVector<Person>(*)>(_a[1]))); break;
        case 1: _t->personUpdate((*reinterpret_cast< const Person(*)>(_a[1]))); break;
        case 2: { bool _r = _t->kill((*reinterpret_cast< KillVerbosity(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->kill();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->onCollectionsReceived((*reinterpret_cast< const Akonadi::Collection::List(*)>(_a[1]))); break;
        case 5: _t->onCollectionsFetched((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 6: _t->onLDAPSearchData((*reinterpret_cast< const KLDAP::LdapResultObject::List(*)>(_a[1]))); break;
        case 7: _t->onLDAPSearchDone(); break;
        case 8: _t->updatePersonCollection((*reinterpret_cast< const Person(*)>(_a[1]))); break;
        case 9: _t->modifyResult((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Collection::List >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (PersonSearchJob::*_t)(const QVector<Person> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PersonSearchJob::personsFound)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (PersonSearchJob::*_t)(const Person & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PersonSearchJob::personUpdate)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KPIM::PersonSearchJob::staticMetaObject = {
    { &KJob::staticMetaObject, qt_meta_stringdata_KPIM__PersonSearchJob.data,
      qt_meta_data_KPIM__PersonSearchJob,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPIM::PersonSearchJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::PersonSearchJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPIM__PersonSearchJob.stringdata0))
        return static_cast<void*>(this);
    return KJob::qt_metacast(_clname);
}

int KPIM::PersonSearchJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KPIM::PersonSearchJob::personsFound(const QVector<Person> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KPIM::PersonSearchJob::personUpdate(const Person & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
