/****************************************************************************
** Meta object code from reading C++ file 'ldapclient.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/libkdepim-17.12.3/src/libkdepim/ldap/ldapclient.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ldapclient.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KLDAP__LdapClient_t {
    QByteArrayData data[13];
    char stringdata0[120];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KLDAP__LdapClient_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KLDAP__LdapClient_t qt_meta_stringdata_KLDAP__LdapClient = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KLDAP::LdapClient"
QT_MOC_LITERAL(1, 18, 4), // "done"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 5), // "error"
QT_MOC_LITERAL(4, 30, 7), // "message"
QT_MOC_LITERAL(5, 38, 6), // "result"
QT_MOC_LITERAL(6, 45, 6), // "client"
QT_MOC_LITERAL(7, 52, 17), // "KLDAP::LdapObject"
QT_MOC_LITERAL(8, 70, 8), // "slotData"
QT_MOC_LITERAL(9, 79, 9), // "KIO::Job*"
QT_MOC_LITERAL(10, 89, 15), // "slotInfoMessage"
QT_MOC_LITERAL(11, 105, 5), // "KJob*"
QT_MOC_LITERAL(12, 111, 8) // "slotDone"

    },
    "KLDAP::LdapClient\0done\0\0error\0message\0"
    "result\0client\0KLDAP::LdapObject\0"
    "slotData\0KIO::Job*\0slotInfoMessage\0"
    "KJob*\0slotDone"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KLDAP__LdapClient[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,
       3,    1,   50,    2, 0x06 /* Public */,
       5,    2,   53,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    2,   58,    2, 0x08 /* Private */,
       8,    1,   63,    2, 0x08 /* Private */,
      10,    3,   66,    2, 0x08 /* Private */,
      12,    0,   73,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, 0x80000000 | 0, 0x80000000 | 7,    6,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 9, QMetaType::QByteArray,    2,    2,
    QMetaType::Void, QMetaType::QByteArray,    2,
    QMetaType::Void, 0x80000000 | 11, QMetaType::QString, QMetaType::QString,    2,    2,    2,
    QMetaType::Void,

       0        // eod
};

void KLDAP::LdapClient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        LdapClient *_t = static_cast<LdapClient *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->done(); break;
        case 1: _t->error((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->result((*reinterpret_cast< const KLDAP::LdapClient(*)>(_a[1])),(*reinterpret_cast< const KLDAP::LdapObject(*)>(_a[2]))); break;
        case 3: _t->d->slotData((*reinterpret_cast< KIO::Job*(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 4: _t->d->slotData((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 5: _t->d->slotInfoMessage((*reinterpret_cast< KJob*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 6: _t->d->slotDone(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (LdapClient::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LdapClient::done)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (LdapClient::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LdapClient::error)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (LdapClient::*_t)(const KLDAP::LdapClient & , const KLDAP::LdapObject & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LdapClient::result)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KLDAP::LdapClient::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KLDAP__LdapClient.data,
      qt_meta_data_KLDAP__LdapClient,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KLDAP::LdapClient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KLDAP::LdapClient::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KLDAP__LdapClient.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KLDAP::LdapClient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KLDAP::LdapClient::done()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KLDAP::LdapClient::error(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KLDAP::LdapClient::result(const KLDAP::LdapClient & _t1, const KLDAP::LdapObject & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
